import { Module } from '@nestjs/common'
import { AppController } from './app.controller'
import { AppService } from './app.service'
import { AuthModule } from './auth/auth.module'
import { ConfigModule, ConfigService } from '@nestjs/config'
import { MongooseModule } from '@nestjs/mongoose'
import { UsersModule } from './users/users.module'
import { SearchController } from './search/search.controller'
import { SearchService } from './search/search.service'
import { SearchModule } from './search/search.module'
import { EventsModule } from './events/events.module'
import { ConnectionsModule } from './connections/connections.module'
import { AnnouncementsModule } from './announcements/announcements.module'

@Module({
  imports: [
    AuthModule,
    ConfigModule.forRoot(),
    MongooseModule.forRootAsync({
      imports: [ConfigModule],
      inject: [ConfigService],
      useFactory: (configService: ConfigService) => ({
        uri: configService.getOrThrow('MONGO_URI'),
      }),
    }),
    ConfigModule,
    UsersModule,
    EventsModule,
    SearchModule,
    AnnouncementsModule,
    ConnectionsModule,
  ],
  controllers: [AppController, SearchController],
  providers: [AppService, SearchService],
})
export class AppModule {}
