import { Prop, Schema, SchemaFactory } from '@nestjs/mongoose'
import { HydratedDocument } from 'mongoose'

export type EventDocument = HydratedDocument<Event>
// export type EventStatus = 'ACTIVE' | 'POSTPONED' | 'CANCELLED' | 'FINISHED'
export enum EventStatus {
  ACTIVE = 'ACTIVE',
  POSTPONED = 'POSTPONED',
  CANCELLED = 'CANCELLED',
  FINISHED = 'FINISHED',
}

// export type ChampionshipLevel =
//   | 'WORLD'
//   | 'CONTINENTAL'
//   | 'INTERNATIONAL'
//   | 'NATIONAL'
//   | 'AMATEUR'

export enum ChampionshipLevel {
  WORLD = 'WORLD',
  CONTINENTAL = 'CONTINENTAL',
  INTERNATIONAL = 'INTERNATIONAL',
  NATIONAL = 'NATIONAL',
  AMATEUR = 'AMATEUR',
}

export type EventCategory = 'CAR' | 'BIKE' | 'PLANE' | 'BOAT' | 'RC' | 'ESPORT'

// export type EventDTO = {
//   id?: number;
//   owner: number; // nem kell
//   status?: EventStatus;
//   name: string;
//   description?: string;
//   image?: string;
//   location?: string;
//   startTime: string; //date!
//   endTime?: string; //date!
//   championshipLevel?: ChampionshipLevel;
//   parentChampionshipId?: number; // ez mi
//   category: EventCategory;
//   bio?: string; // ez mi
//   extras?: string; // ez mi
//   notice?: string; // ez mi
//   rosterName?: string;
//   rosterUrl?: string;
//   children?: EventEntity[]; // ez mi
// };

@Schema()
export class Event {
  @Prop({ required: true })
  name: string

  @Prop({
    required: true,
    enum: ['ACTIVE', 'POSTPONED', 'CANCELLED', 'FINISHED'],
  })
  status: EventStatus

  @Prop()
  description: string

  @Prop()
  image: string

  @Prop()
  location: string

  @Prop()
  startTime: Date

  @Prop()
  endTime: Date

  @Prop()
  @Prop({
    required: true,
    enum: ['WORLD', 'CONTINENTAL', 'INTERNATIONAL', 'NATIONAL', 'AMATEUR'],
  })
  championshipLevel: ChampionshipLevel

  @Prop({
    required: true,
    enum: ['CAR', 'BIKE', 'PLANE', 'BOAT', 'RC', 'ESPORT'],
  })
  category: string

  @Prop()
  rosterName: string

  @Prop()
  rosterUrl: string
}

export const EventSchema = SchemaFactory.createForClass(Event)
